@@ -12,7 +12,7 @@ public class FilesetDV implements Serializable {
 	 */
 	private static final long serialVersionUID = -3108729581669778828L;
 	private String name;
-	private List<PayloadDV> listPayloads;
+	private List<PayloadDV> listPayloads = new ArrayList<PayloadDV>();
 
 	public FilesetDV() {
 
@@ -31,16 +31,10 @@ public class FilesetDV implements Serializable {
 	}
 
 	public void addPayloadDV(PayloadDV payloadDV) {
-		if (listPayloads == null)
-			listPayloads = new ArrayList<PayloadDV>();
-
 		listPayloads.add(payloadDV);
 	}
 
 	public void addListPayloadsDV(List<PayloadDV> listPayloadsDV) {
-		if (listPayloads == null)
-			listPayloads = new ArrayList<PayloadDV>();
-
 		listPayloads.addAll(listPayloadsDV);
 	}
 
